==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>트레이 아이콘 클릭 
또는 단축키를 다시 눌러 녹화를 중지하십시오</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>녹화하기</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>화면 캡처</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>저장하지 못했습니다. 홈 디렉토리에 저장하십시오.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>스크린샷 완료</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>선택 영역</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1에 저장됨</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>재실행</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>녹화 완료</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1에 저장됨</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>녹화하기</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>화면 캡처는 %1초에 시작됩니다</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>여기에 텍스트 입력</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>시작/스크린샷</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>종료/저장</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>그리기</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>크기 조정</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>빠른 시작</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>창 스크린샷</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>지연 스크린샷</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>전체 스크린샷</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>사각형</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>원형</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>연필</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>재실행</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>높이 위로 증가</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>높이 아래로 증가</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>왼쪽 너비 증가</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>오른쪽 너비 증가</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>높이 위로 감소</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>높이 아래로 감소</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>왼쪽 너비 감소</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>오른쪽 너비 감소</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation>녹화 시작</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>흐림</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>모자이크</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>사운드 켜기</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>마이크</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>시스템 오디오</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>사운드 끄기</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>키입력 표시</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>키입력 숨기기</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>웹캠 켜기</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>웹캠 끄기</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>클릭 표시</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>형식:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>사각형</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>원형</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>화살표</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>연필</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>저장 위치</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>바탕화면</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>폴더</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>형식</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>녹화</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>트레이 아이콘 클릭&#xa0;
또는 단축키를 다시 눌러 녹화를 중지하십시오</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>녹화하기</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>화면 캡처</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>저장하지 못했습니다. 홈 디렉토리에 저장하십시오.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>스크린샷 완료</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>선택 영역</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1에 저장됨</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>재실행</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>녹화 완료</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1에 저장됨</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>녹화하기</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>화면 캡처는 %1초에 시작됩니다</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>여기에 텍스트 입력</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>시작/스크린샷</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>종료/저장</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>크기 조정</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>빠른 시작</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>창 스크린샷</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>지연 스크린샷</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>전체 스크린샷</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>사각형</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>원형</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>연필</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>재실행</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>높이 위로 증가</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>높이 아래로 증가</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>왼쪽 너비 증가</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>오른쪽 너비 증가</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>높이 위로 감소</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>높이 아래로 감소</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>왼쪽 너비 감소</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>오른쪽 너비 감소</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>녹화 시작</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>흐림</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>모자이크</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>사운드 켜기</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>마이크</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>시스템 오디오</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>사운드 끄기</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>키입력 표시</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>키입력 숨기기</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>웹캠 켜기</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>웹캠 끄기</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>클릭 표시</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>형식:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>사각형</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>원형</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>선</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>화살표</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>연필</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>저장 위치</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>바탕화면</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>폴더</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>형식</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">종료</translation>
    </message>
</context>
</TS>
